"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const make_error_1 = require("make-error");
/**
 * Create error message from missing and invalid parameters.
 */
function makeMessage(missing, invalid) {
    const message = [];
    if (missing.length) {
        const details = missing.join(", ");
        message.push(`Missing values: ${details}`);
    }
    if (invalid.length) {
        const details = invalid
            .map(([key, value]) => `${String(key)}: ${value}`)
            .join(", ");
        message.push(`Invalid values: ${details}`);
    }
    return message.join("; ");
}
/**
 * Invalid environment error.
 */
class InvalidEnvError extends make_error_1.BaseError {
    constructor(missing, invalid) {
        super(makeMessage(missing, invalid));
        this.missing = missing;
        this.invalid = invalid;
    }
}
exports.InvalidEnvError = InvalidEnvError;
/**
 * Tiny environment variable helper.
 */
function envobj(schema, source, ...sources) {
    const env = Object.create(null);
    const missing = [];
    const invalid = [];
    for (const key of Object.keys(schema)) {
        let value = source[key];
        for (const source of sources) {
            if (value !== undefined)
                break;
            value = source[key];
        }
        if (value === undefined) {
            missing.push(key);
        }
        else {
            const result = schema[key](value);
            if (result === undefined)
                invalid.push([key, value]);
            env[key] = result;
        }
    }
    // Throw on invalid environment.
    if (invalid.length || missing.length) {
        throw new InvalidEnvError(missing, invalid);
    }
    return env;
}
exports.envobj = envobj;
/**
 * Parse string variable.
 */
exports.string = (input) => String(input);
/**
 * Parse boolean variable.
 */
exports.boolean = (input) => {
    const value = input.toLowerCase();
    if (value === "true")
        return true;
    if (value === "false")
        return false;
    return undefined;
};
/**
 * Parse numeric variable.
 */
exports.number = (input) => {
    const value = Number(input);
    if (isNaN(value))
        return undefined;
    return value;
};
/**
 * Parse integer variable.
 */
exports.integer = (input) => {
    const value = Number(input);
    if (isNaN(value) || value % 1 !== 0)
        return undefined;
    return value;
};
//# sourceMappingURL=index.js.map